==> zio-aws-athena_3-5.19.8.2-sources.jar: zio/aws/athena/model/package.scala <==
package zio.aws.athena
import zio.aws.athena.model.primitives.{
  QueryExecutionId,
  KeyString,
  Integer,
  ParametersMapValue,
  NamedQueryId,
  ExecutionParameter,
  StatementName,
  TagKey
}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.athena.model.primitives.MaxTableMetadataCount.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Age extends Subtype[Int]
    type Age = zio.aws.athena.model.primitives.Age.Type
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.athena.model.primitives.AmazonResourceName.Type
    object AuthToken extends Subtype[String]
    type AuthToken = zio.aws.athena.model.primitives.AuthToken.Type
    object AwsAccountId extends Subtype[String]
    type AwsAccountId = zio.aws.athena.model.primitives.AwsAccountId.Type
    type BoxedBoolean = Boolean
    object BytesScannedCutoffValue extends Subtype[Long]
    type BytesScannedCutoffValue =
      zio.aws.athena.model.primitives.BytesScannedCutoffValue.Type
    object CalculationExecutionId extends Subtype[String]
    type CalculationExecutionId =
      zio.aws.athena.model.primitives.CalculationExecutionId.Type
    object CalculationResultType extends Subtype[String]
    type CalculationResultType =
      zio.aws.athena.model.primitives.CalculationResultType.Type
    object CatalogNameString extends Subtype[String]
    type CatalogNameString =
      zio.aws.athena.model.primitives.CatalogNameString.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.athena.model.primitives.ClientRequestToken.Type
    object CodeBlock extends Subtype[String]
    type CodeBlock = zio.aws.athena.model.primitives.CodeBlock.Type
    object CommentString extends Subtype[String]
    type CommentString = zio.aws.athena.model.primitives.CommentString.Type
    object CoordinatorDpuSize extends Subtype[Int]
    type CoordinatorDpuSize =
      zio.aws.athena.model.primitives.CoordinatorDpuSize.Type
    object DatabaseString extends Subtype[String]
    type DatabaseString = zio.aws.athena.model.primitives.DatabaseString.Type
    object Date extends Subtype[Instant]
    type Date = zio.aws.athena.model.primitives.Date.Type
    object DatumString extends Subtype[String]
    type DatumString = zio.aws.athena.model.primitives.DatumString.Type
    object DefaultExecutorDpuSize extends Subtype[Int]
    type DefaultExecutorDpuSize =
      zio.aws.athena.model.primitives.DefaultExecutorDpuSize.Type
    object DescriptionString extends Subtype[String]
    type DescriptionString =
      zio.aws.athena.model.primitives.DescriptionString.Type
    object ErrorCategory extends Subtype[Int]
    type ErrorCategory = zio.aws.athena.model.primitives.ErrorCategory.Type
    object ErrorCode extends Subtype[String]
    type ErrorCode = zio.aws.athena.model.primitives.ErrorCode.Type
    object ErrorMessage extends Subtype[String]
    type ErrorMessage = zio.aws.athena.model.primitives.ErrorMessage.Type
    object ErrorType extends Subtype[Int]
    type ErrorType = zio.aws.athena.model.primitives.ErrorType.Type
    object ExecutionParameter extends Subtype[String]
    type ExecutionParameter =
      zio.aws.athena.model.primitives.ExecutionParameter.Type
    object ExecutorId extends Subtype[String]
    type ExecutorId = zio.aws.athena.model.primitives.ExecutorId.Type
    object ExpressionString extends Subtype[String]
    type ExpressionString =
      zio.aws.athena.model.primitives.ExpressionString.Type
    object IdempotencyToken extends Subtype[String]
    type IdempotencyToken =
      zio.aws.athena.model.primitives.IdempotencyToken.Type
    type Integer = Int
    object KeyString extends Subtype[String]
    type KeyString = zio.aws.athena.model.primitives.KeyString.Type
    object KmsKey extends Subtype[String]
    type KmsKey = zio.aws.athena.model.primitives.KmsKey.Type
    object MaxApplicationDPUSizesCount extends Subtype[Int]
    type MaxApplicationDPUSizesCount =
      zio.aws.athena.model.primitives.MaxApplicationDPUSizesCount.Type
    object MaxCalculationsCount extends Subtype[Int]
    type MaxCalculationsCount =
      zio.aws.athena.model.primitives.MaxCalculationsCount.Type
    object MaxConcurrentDpus extends Subtype[Int]
    type MaxConcurrentDpus =
      zio.aws.athena.model.primitives.MaxConcurrentDpus.Type
    object MaxDataCatalogsCount extends Subtype[Int]
    type MaxDataCatalogsCount =
      zio.aws.athena.model.primitives.MaxDataCatalogsCount.Type
    object MaxDatabasesCount extends Subtype[Int]
    type MaxDatabasesCount =
      zio.aws.athena.model.primitives.MaxDatabasesCount.Type
    object MaxEngineVersionsCount extends Subtype[Int]
    type MaxEngineVersionsCount =
      zio.aws.athena.model.primitives.MaxEngineVersionsCount.Type
    object MaxListExecutorsCount extends Subtype[Int]
    type MaxListExecutorsCount =
      zio.aws.athena.model.primitives.MaxListExecutorsCount.Type
    object MaxNamedQueriesCount extends Subtype[Int]
    type MaxNamedQueriesCount =
      zio.aws.athena.model.primitives.MaxNamedQueriesCount.Type
    object MaxNotebooksCount extends Subtype[Int]
    type MaxNotebooksCount =
      zio.aws.athena.model.primitives.MaxNotebooksCount.Type
    object MaxPreparedStatementsCount extends Subtype[Int]
    type MaxPreparedStatementsCount =
      zio.aws.athena.model.primitives.MaxPreparedStatementsCount.Type
    object MaxQueryExecutionsCount extends Subtype[Int]
    type MaxQueryExecutionsCount =
      zio.aws.athena.model.primitives.MaxQueryExecutionsCount.Type
    object MaxQueryResults extends Subtype[Int]
    type MaxQueryResults = zio.aws.athena.model.primitives.MaxQueryResults.Type
    object MaxSessionsCount extends Subtype[Int]
    type MaxSessionsCount =
      zio.aws.athena.model.primitives.MaxSessionsCount.Type
    object MaxTableMetadataCount extends Subtype[Int]
    type MaxTableMetadataCount =
      zio.aws.athena.model.primitives.MaxTableMetadataCount.Type
    object MaxTagsCount extends Subtype[Int]
    type MaxTagsCount = zio.aws.athena.model.primitives.MaxTagsCount.Type
    object MaxWorkGroupsCount extends Subtype[Int]
    type MaxWorkGroupsCount =
      zio.aws.athena.model.primitives.MaxWorkGroupsCount.Type
    object NameString extends Subtype[String]
    type NameString = zio.aws.athena.model.primitives.NameString.Type
    object NamedQueryDescriptionString extends Subtype[String]
    type NamedQueryDescriptionString =
      zio.aws.athena.model.primitives.NamedQueryDescriptionString.Type
    object NamedQueryId extends Subtype[String]
    type NamedQueryId = zio.aws.athena.model.primitives.NamedQueryId.Type
    object NotebookId extends Subtype[String]
    type NotebookId = zio.aws.athena.model.primitives.NotebookId.Type
    object NotebookName extends Subtype[String]
    type NotebookName = zio.aws.athena.model.primitives.NotebookName.Type
    object ParametersMapValue extends Subtype[String]
    type ParametersMapValue =
      zio.aws.athena.model.primitives.ParametersMapValue.Type
    object Payload extends Subtype[String]
    type Payload = zio.aws.athena.model.primitives.Payload.Type
    object QueryExecutionId extends Subtype[String]
    type QueryExecutionId =
      zio.aws.athena.model.primitives.QueryExecutionId.Type
    object QueryString extends Subtype[String]
    type QueryString = zio.aws.athena.model.primitives.QueryString.Type
    object ResultOutputLocation extends Subtype[String]
    type ResultOutputLocation =
      zio.aws.athena.model.primitives.ResultOutputLocation.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.athena.model.primitives.RoleArn.Type
    object S3Uri extends Subtype[String]
    type S3Uri = zio.aws.athena.model.primitives.S3Uri.Type
    object SessionId extends Subtype[String]
    type SessionId = zio.aws.athena.model.primitives.SessionId.Type
    object SessionIdleTimeoutInMinutes extends Subtype[Int]
    type SessionIdleTimeoutInMinutes =
      zio.aws.athena.model.primitives.SessionIdleTimeoutInMinutes.Type
    object SessionManagerToken extends Subtype[String]
    type SessionManagerToken =
      zio.aws.athena.model.primitives.SessionManagerToken.Type
    object StatementName extends Subtype[String]
    type StatementName = zio.aws.athena.model.primitives.StatementName.Type
    object TableTypeString extends Subtype[String]
    type TableTypeString = zio.aws.athena.model.primitives.TableTypeString.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.athena.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.athena.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.athena.model.primitives.Timestamp.Type
    object Token extends Subtype[String]
    type Token = zio.aws.athena.model.primitives.Token.Type
    object TypeString extends Subtype[String]
    type TypeString = zio.aws.athena.model.primitives.TypeString.Type
    object WorkGroupDescriptionString extends Subtype[String]
    type WorkGroupDescriptionString =
      zio.aws.athena.model.primitives.WorkGroupDescriptionString.Type
    object WorkGroupName extends Subtype[String]
    type WorkGroupName = zio.aws.athena.model.primitives.WorkGroupName.Type
  }
  type ApplicationDPUSizesList = List[zio.aws.athena.model.ApplicationDPUSizes]
  type CalculationsList = List[zio.aws.athena.model.CalculationSummary]
  type ColumnInfoList = List[zio.aws.athena.model.ColumnInfo]
  type ColumnList = List[zio.aws.athena.model.Column]
  type DataCatalogSummaryList = List[zio.aws.athena.model.DataCatalogSummary]
  type DatabaseList = List[zio.aws.athena.model.Database]
  type DatumList = List[zio.aws.athena.model.Datum]
  type EngineVersionsList = List[zio.aws.athena.model.EngineVersion]
  type ExecutionParameters = List[ExecutionParameter]
  type ExecutorsSummaryList = List[zio.aws.athena.model.ExecutorsSummary]
  type NamedQueryIdList = List[NamedQueryId]
  type NamedQueryList = List[zio.aws.athena.model.NamedQuery]
  type NotebookMetadataArray = List[zio.aws.athena.model.NotebookMetadata]
  type NotebookSessionsList = List[zio.aws.athena.model.NotebookSessionSummary]
  type ParametersMap = Map[KeyString, ParametersMapValue]
  type PreparedStatementDetailsList =
    List[zio.aws.athena.model.PreparedStatement]
  type PreparedStatementNameList = List[StatementName]
  type PreparedStatementsList =
    List[zio.aws.athena.model.PreparedStatementSummary]
  type QueryExecutionIdList = List[QueryExecutionId]
  type QueryExecutionList = List[zio.aws.athena.model.QueryExecution]
  type QueryStagePlanNodes = List[zio.aws.athena.model.QueryStagePlanNode]
  type QueryStages = List[zio.aws.athena.model.QueryStage]
  type RowList = List[zio.aws.athena.model.Row]
  type SessionsList = List[zio.aws.athena.model.SessionSummary]
  type StringList = List[String]
  type SupportedDPUSizeList = List[Integer]
  type TableMetadataList = List[zio.aws.athena.model.TableMetadata]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.athena.model.Tag]
  type UnprocessedNamedQueryIdList =
    List[zio.aws.athena.model.UnprocessedNamedQueryId]
  type UnprocessedPreparedStatementNameList =
    List[zio.aws.athena.model.UnprocessedPreparedStatementName]
  type UnprocessedQueryExecutionIdList =
    List[zio.aws.athena.model.UnprocessedQueryExecutionId]
  type WorkGroupsList = List[zio.aws.athena.model.WorkGroupSummary]
}

==> zio-aws-athena_3-7.21.15.2-sources.jar: zio/aws/athena/model/package.scala <==
package zio.aws.athena
import zio.aws.athena.model.primitives.{
  QueryExecutionId,
  KeyString,
  WorkGroupName,
  Integer,
  ParametersMapValue,
  NamedQueryId,
  ExecutionParameter,
  StatementName,
  TagKey
}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.athena.model.primitives.MaxTableMetadataCount.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Age extends Subtype[Int]
    type Age = zio.aws.athena.model.primitives.Age.Type
    object AllocatedDpusInteger extends Subtype[Int]
    type AllocatedDpusInteger =
      zio.aws.athena.model.primitives.AllocatedDpusInteger.Type
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.athena.model.primitives.AmazonResourceName.Type
    object AuthToken extends Subtype[String]
    type AuthToken = zio.aws.athena.model.primitives.AuthToken.Type
    object AwsAccountId extends Subtype[String]
    type AwsAccountId = zio.aws.athena.model.primitives.AwsAccountId.Type
    type BoxedBoolean = Boolean
    object BytesScannedCutoffValue extends Subtype[Long]
    type BytesScannedCutoffValue =
      zio.aws.athena.model.primitives.BytesScannedCutoffValue.Type
    object CalculationExecutionId extends Subtype[String]
    type CalculationExecutionId =
      zio.aws.athena.model.primitives.CalculationExecutionId.Type
    object CalculationResultType extends Subtype[String]
    type CalculationResultType =
      zio.aws.athena.model.primitives.CalculationResultType.Type
    object CapacityReservationName extends Subtype[String]
    type CapacityReservationName =
      zio.aws.athena.model.primitives.CapacityReservationName.Type
    object CatalogNameString extends Subtype[String]
    type CatalogNameString =
      zio.aws.athena.model.primitives.CatalogNameString.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.athena.model.primitives.ClientRequestToken.Type
    object CodeBlock extends Subtype[String]
    type CodeBlock = zio.aws.athena.model.primitives.CodeBlock.Type
    object CommentString extends Subtype[String]
    type CommentString = zio.aws.athena.model.primitives.CommentString.Type
    object CoordinatorDpuSize extends Subtype[Int]
    type CoordinatorDpuSize =
      zio.aws.athena.model.primitives.CoordinatorDpuSize.Type
    object DatabaseString extends Subtype[String]
    type DatabaseString = zio.aws.athena.model.primitives.DatabaseString.Type
    object Date extends Subtype[Instant]
    type Date = zio.aws.athena.model.primitives.Date.Type
    object DatumString extends Subtype[String]
    type DatumString = zio.aws.athena.model.primitives.DatumString.Type
    object DefaultExecutorDpuSize extends Subtype[Int]
    type DefaultExecutorDpuSize =
      zio.aws.athena.model.primitives.DefaultExecutorDpuSize.Type
    object DescriptionString extends Subtype[String]
    type DescriptionString =
      zio.aws.athena.model.primitives.DescriptionString.Type
    object ErrorCategory extends Subtype[Int]
    type ErrorCategory = zio.aws.athena.model.primitives.ErrorCategory.Type
    object ErrorCode extends Subtype[String]
    type ErrorCode = zio.aws.athena.model.primitives.ErrorCode.Type
    object ErrorMessage extends Subtype[String]
    type ErrorMessage = zio.aws.athena.model.primitives.ErrorMessage.Type
    object ErrorType extends Subtype[Int]
    type ErrorType = zio.aws.athena.model.primitives.ErrorType.Type
    object ExecutionParameter extends Subtype[String]
    type ExecutionParameter =
      zio.aws.athena.model.primitives.ExecutionParameter.Type
    object ExecutorId extends Subtype[String]
    type ExecutorId = zio.aws.athena.model.primitives.ExecutorId.Type
    object ExpressionString extends Subtype[String]
    type ExpressionString =
      zio.aws.athena.model.primitives.ExpressionString.Type
    object IdempotencyToken extends Subtype[String]
    type IdempotencyToken =
      zio.aws.athena.model.primitives.IdempotencyToken.Type
    type Integer = Int
    object KeyString extends Subtype[String]
    type KeyString = zio.aws.athena.model.primitives.KeyString.Type
    object KmsKey extends Subtype[String]
    type KmsKey = zio.aws.athena.model.primitives.KmsKey.Type
    object MaxApplicationDPUSizesCount extends Subtype[Int]
    type MaxApplicationDPUSizesCount =
      zio.aws.athena.model.primitives.MaxApplicationDPUSizesCount.Type
    object MaxCalculationsCount extends Subtype[Int]
    type MaxCalculationsCount =
      zio.aws.athena.model.primitives.MaxCalculationsCount.Type
    object MaxCapacityReservationsCount extends Subtype[Int]
    type MaxCapacityReservationsCount =
      zio.aws.athena.model.primitives.MaxCapacityReservationsCount.Type
    object MaxConcurrentDpus extends Subtype[Int]
    type MaxConcurrentDpus =
      zio.aws.athena.model.primitives.MaxConcurrentDpus.Type
    object MaxDataCatalogsCount extends Subtype[Int]
    type MaxDataCatalogsCount =
      zio.aws.athena.model.primitives.MaxDataCatalogsCount.Type
    object MaxDatabasesCount extends Subtype[Int]
    type MaxDatabasesCount =
      zio.aws.athena.model.primitives.MaxDatabasesCount.Type
    object MaxEngineVersionsCount extends Subtype[Int]
    type MaxEngineVersionsCount =
      zio.aws.athena.model.primitives.MaxEngineVersionsCount.Type
    object MaxListExecutorsCount extends Subtype[Int]
    type MaxListExecutorsCount =
      zio.aws.athena.model.primitives.MaxListExecutorsCount.Type
    object MaxNamedQueriesCount extends Subtype[Int]
    type MaxNamedQueriesCount =
      zio.aws.athena.model.primitives.MaxNamedQueriesCount.Type
    object MaxNotebooksCount extends Subtype[Int]
    type MaxNotebooksCount =
      zio.aws.athena.model.primitives.MaxNotebooksCount.Type
    object MaxPreparedStatementsCount extends Subtype[Int]
    type MaxPreparedStatementsCount =
      zio.aws.athena.model.primitives.MaxPreparedStatementsCount.Type
    object MaxQueryExecutionsCount extends Subtype[Int]
    type MaxQueryExecutionsCount =
      zio.aws.athena.model.primitives.MaxQueryExecutionsCount.Type
    object MaxQueryResults extends Subtype[Int]
    type MaxQueryResults = zio.aws.athena.model.primitives.MaxQueryResults.Type
    object MaxSessionsCount extends Subtype[Int]
    type MaxSessionsCount =
      zio.aws.athena.model.primitives.MaxSessionsCount.Type
    object MaxTableMetadataCount extends Subtype[Int]
    type MaxTableMetadataCount =
      zio.aws.athena.model.primitives.MaxTableMetadataCount.Type
    object MaxTagsCount extends Subtype[Int]
    type MaxTagsCount = zio.aws.athena.model.primitives.MaxTagsCount.Type
    object MaxWorkGroupsCount extends Subtype[Int]
    type MaxWorkGroupsCount =
      zio.aws.athena.model.primitives.MaxWorkGroupsCount.Type
    object NameString extends Subtype[String]
    type NameString = zio.aws.athena.model.primitives.NameString.Type
    object NamedQueryDescriptionString extends Subtype[String]
    type NamedQueryDescriptionString =
      zio.aws.athena.model.primitives.NamedQueryDescriptionString.Type
    object NamedQueryId extends Subtype[String]
    type NamedQueryId = zio.aws.athena.model.primitives.NamedQueryId.Type
    object NotebookId extends Subtype[String]
    type NotebookId = zio.aws.athena.model.primitives.NotebookId.Type
    object NotebookName extends Subtype[String]
    type NotebookName = zio.aws.athena.model.primitives.NotebookName.Type
    object ParametersMapValue extends Subtype[String]
    type ParametersMapValue =
      zio.aws.athena.model.primitives.ParametersMapValue.Type
    object Payload extends Subtype[String]
    type Payload = zio.aws.athena.model.primitives.Payload.Type
    object QueryExecutionId extends Subtype[String]
    type QueryExecutionId =
      zio.aws.athena.model.primitives.QueryExecutionId.Type
    object QueryString extends Subtype[String]
    type QueryString = zio.aws.athena.model.primitives.QueryString.Type
    object ResultOutputLocation extends Subtype[String]
    type ResultOutputLocation =
      zio.aws.athena.model.primitives.ResultOutputLocation.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.athena.model.primitives.RoleArn.Type
    object S3Uri extends Subtype[String]
    type S3Uri = zio.aws.athena.model.primitives.S3Uri.Type
    object SessionId extends Subtype[String]
    type SessionId = zio.aws.athena.model.primitives.SessionId.Type
    object SessionIdleTimeoutInMinutes extends Subtype[Int]
    type SessionIdleTimeoutInMinutes =
      zio.aws.athena.model.primitives.SessionIdleTimeoutInMinutes.Type
    object SessionManagerToken extends Subtype[String]
    type SessionManagerToken =
      zio.aws.athena.model.primitives.SessionManagerToken.Type
    object StatementName extends Subtype[String]
    type StatementName = zio.aws.athena.model.primitives.StatementName.Type
    object TableTypeString extends Subtype[String]
    type TableTypeString = zio.aws.athena.model.primitives.TableTypeString.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.athena.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.athena.model.primitives.TagValue.Type
    object TargetDpusInteger extends Subtype[Int]
    type TargetDpusInteger =
      zio.aws.athena.model.primitives.TargetDpusInteger.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.athena.model.primitives.Timestamp.Type
    object Token extends Subtype[String]
    type Token = zio.aws.athena.model.primitives.Token.Type
    object TypeString extends Subtype[String]
    type TypeString = zio.aws.athena.model.primitives.TypeString.Type
    object WorkGroupDescriptionString extends Subtype[String]
    type WorkGroupDescriptionString =
      zio.aws.athena.model.primitives.WorkGroupDescriptionString.Type
    object WorkGroupName extends Subtype[String]
    type WorkGroupName = zio.aws.athena.model.primitives.WorkGroupName.Type
  }
  type ApplicationDPUSizesList = List[zio.aws.athena.model.ApplicationDPUSizes]
  type CalculationsList = List[zio.aws.athena.model.CalculationSummary]
  type CapacityAssignmentsList = List[zio.aws.athena.model.CapacityAssignment]
  type CapacityReservationsList = List[zio.aws.athena.model.CapacityReservation]
  type ColumnInfoList = List[zio.aws.athena.model.ColumnInfo]
  type ColumnList = List[zio.aws.athena.model.Column]
  type DataCatalogSummaryList = List[zio.aws.athena.model.DataCatalogSummary]
  type DatabaseList = List[zio.aws.athena.model.Database]
  type DatumList = List[zio.aws.athena.model.Datum]
  type EngineVersionsList = List[zio.aws.athena.model.EngineVersion]
  type ExecutionParameters = List[ExecutionParameter]
  type ExecutorsSummaryList = List[zio.aws.athena.model.ExecutorsSummary]
  type NamedQueryIdList = List[NamedQueryId]
  type NamedQueryList = List[zio.aws.athena.model.NamedQuery]
  type NotebookMetadataArray = List[zio.aws.athena.model.NotebookMetadata]
  type NotebookSessionsList = List[zio.aws.athena.model.NotebookSessionSummary]
  type ParametersMap = Map[KeyString, ParametersMapValue]
  type PreparedStatementDetailsList =
    List[zio.aws.athena.model.PreparedStatement]
  type PreparedStatementNameList = List[StatementName]
  type PreparedStatementsList =
    List[zio.aws.athena.model.PreparedStatementSummary]
  type QueryExecutionIdList = List[QueryExecutionId]
  type QueryExecutionList = List[zio.aws.athena.model.QueryExecution]
  type QueryStagePlanNodes = List[zio.aws.athena.model.QueryStagePlanNode]
  type QueryStages = List[zio.aws.athena.model.QueryStage]
  type RowList = List[zio.aws.athena.model.Row]
  type SessionsList = List[zio.aws.athena.model.SessionSummary]
  type StringList = List[String]
  type SupportedDPUSizeList = List[Integer]
  type TableMetadataList = List[zio.aws.athena.model.TableMetadata]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.athena.model.Tag]
  type UnprocessedNamedQueryIdList =
    List[zio.aws.athena.model.UnprocessedNamedQueryId]
  type UnprocessedPreparedStatementNameList =
    List[zio.aws.athena.model.UnprocessedPreparedStatementName]
  type UnprocessedQueryExecutionIdList =
    List[zio.aws.athena.model.UnprocessedQueryExecutionId]
  type WorkGroupNamesList = List[WorkGroupName]
  type WorkGroupsList = List[zio.aws.athena.model.WorkGroupSummary]
}
